@@ -24,7 +24,7 @@ if __name__=='pymol.creating':
     import gzip
     import os
     from .cmd import _cmd, Shortcut, is_list, is_string, \
-          file_ext_re, safe_list_eval, safe_alpha_list_eval, \
+          safe_list_eval, safe_alpha_list_eval, \
           DEFAULT_ERROR, DEFAULT_SUCCESS, is_ok, is_error, \
           is_tuple
     import tempfile
@@ -1124,9 +1124,6 @@ NOTES
             color = _self.get_color_index(str(color))
         else:
             color = -1 # default
-        object = str(object)
-        if not len(object):
-            object = _self.get_unused_name(prefix="pseudo")
         selection = selector.process(selection)
         mode = pseudoatom_mode_dict[pseudoatom_mode_sc.auto_err(str(mode),'pseudoatom mode')]
         
